package com.persagy.dmp.starter.alarm.communication.mq;

import com.persagy.dmp.starter.alarm.communication.netty.NettyAlarmMsgBaseHandler;
import com.persagy.zkt.utils.StringUtil;
import com.rabbitmq.client.Channel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @description:报警定义消息通知
 * @author:LuoGuangyi
 * @company:PersagyTechnologyCo.,Ltd
 * @since:2020/10/20 002016:30
 * @version:V1.0
 **/
@Slf4j
@Configuration
public class JmsConfig {

	/**
	 * NettyAlarmMsgBaseHandler本身不进行ioc注入，这里注入的是他的子类。
	 * 子类在实际项目中创建，starter中没有实例。
	 */
	@Autowired
	private NettyAlarmMsgBaseHandler msgHandler;
	/**
	 * 报警定义变化类型
	 */
	private static final String ALARM_CONFIGS_CHANGE = "alarmConfigsChange";
	/**
	 * 报警交换器
	 */
	@Value("${dmp.alarm.exchange}")
	private String exchange;
	/**
	 * 报警路由键
	 */
	@Value("${dmp.alarm.routingKey}")
	private String alarmRoutingKey;
	/**
	 * 报警队列
	 */
	@Value("${dmp.alarm.queue}")
	private String alarmQueue;


	@Bean
	public Queue queue() {
		return new Queue(alarmQueue, true);
	}

	@Bean
	public TopicExchange exchange() {
		return new TopicExchange(exchange);
	}

	@Bean
	public Binding alarmBinding() {
		return BindingBuilder.bind(queue()).to(exchange()).with(alarmRoutingKey);
	}

	@RabbitHandler
	@RabbitListener(queues = "${dmp.alarm.queue}")
	public void planQueues(String msg, Channel channel, Message message) throws Exception {
		log.info("============================== Receive:" + msg);
		DmpMessage dmpMessage = StringUtil.tranferItemToDTO(msg, DmpMessage.class);
		//报警定义变化
		if(ALARM_CONFIGS_CHANGE.equals(dmpMessage.getType())){
			log.info("================收到一条报警定义变化通知==============");
			log.info(msg.toString());
			try {
				msgHandler.incrementSyncAlarmConfig(dmpMessage);
			} catch (Exception e) {
				log.error("error",e);
			}
		}
	}
}
