package com.persagy.dmp.starter.alarm.feign;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.dmp.starter.alarm.feign.client.AlarmClient;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;


/**
 * @description: 降级处理
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/11/27 2:05 下午
 * @version: V1.0
 */
@Slf4j
public class AlarmServerFallbackFactory implements FallbackFactory<AlarmClient> {
    @Override
    public AlarmClient create(Throwable throwable) {
       return new AlarmClient() {
           private String errorMsg = "feign调用报警中心接口异常，接口名称：[{}], 请求体：[{}]";

           @Override
           public DmpResult<JSONArray> queryAlarmConfig(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
               throw new Exception(String.format(errorMsg, "queryAlarmConfig", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONObject> createAlarmConfig(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "createAlarmConfig", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONObject> updateAlarmConfig(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "updateAlarmConfig", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONArray> queryAlarmRecord(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "queryAlarmRecord", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONObject> createAlarmRecord(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "createAlarmRecord", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONObject> updateAlarmRecord(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "updateAlarmRecord", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONArray> queryAlarmItem(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "queryAlarmItem", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONObject> createAlarmComment(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "createAlarmComment", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONArray> queryAlarmComment(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception{
               throw new Exception(String.format(errorMsg, "queryAlarmComment", jsonObject.toString()));
           }

           @Override
           public DmpResult<JSONArray> queryAlarmDic(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
               throw new Exception(String.format(errorMsg, "queryAlarmDic", jsonObject.toString()));
           }
       };
    }
}
