package com.persagy.dmp.starter.alarm.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.dmp.starter.alarm.feign.AlarmUrlParam;
import com.persagy.dmp.starter.alarm.feign.DmpResult;
import com.persagy.dmp.starter.alarm.feign.client.AlarmClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @description:
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/11/27 6:57 下午
 * @version: V1.0
 **/
@Service
public class AlarmService {
    @Autowired
    private AlarmClient alarmClient;

    /**
     * @description: 查询报警定义
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONArray>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONArray> queryAlarmConfig(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.queryAlarmConfig(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 创建报警定义
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONObject>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONObject> createAlarmConfig(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.createAlarmConfig(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 更新报警定义
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONObject>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONObject> updateAlarmConfig(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.updateAlarmConfig(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 查询报警记录
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONArray>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONArray> queryAlarmRecord(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.queryAlarmRecord(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 创建报警记录
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONObject>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONObject> createAlarmRecord(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.createAlarmRecord(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 更新报警记录
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONObject>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONObject> updateAlarmRecord(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.updateAlarmRecord(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 查询报警条目
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONArray>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:41 下午
     * @version: V1.0
     */
    public DmpResult<JSONArray> queryAlarmItem(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.queryAlarmItem(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 创建报警批注
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONObject>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:42 下午
     * @version: V1.0
     */
    public DmpResult<JSONObject> createAlarmComment(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.createAlarmComment(alarmUrlParam, jsonObject);
    }

    /**
     * @description: 查询报警批注
     * @param: alarmUrlParam
     * @param: jsonObject
     * @return: com.persagy.dmp.starter.alarm.feign.DmpResult<org.springframework.boot.configurationprocessor.json.JSONArray>
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/11/27 3:42 下午
     * @version: V1.0
     */
    public DmpResult<JSONArray> queryAlarmComment(AlarmUrlParam alarmUrlParam, JSONObject jsonObject) throws Exception {
        return alarmClient.queryAlarmComment(alarmUrlParam, jsonObject);
    }

}
